Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(369)

Unified Diff: content/browser/frame_host/navigation_request.cc

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: add back previews_unspecified Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/navigation_request.cc
diff --git a/content/browser/frame_host/navigation_request.cc b/content/browser/frame_host/navigation_request.cc
index cfdd32db8acb5b0bf01b7fa280952e70a5230739..8f0364e65124628108992555aa0f2c16049494a1 100644
--- a/content/browser/frame_host/navigation_request.cc
+++ b/content/browser/frame_host/navigation_request.cc
@@ -145,7 +145,7 @@ std::unique_ptr<NavigationRequest> NavigationRequest::CreateBrowserInitiated(
const FrameNavigationEntry& frame_entry,
const NavigationEntryImpl& entry,
FrameMsg_Navigate_Type::Value navigation_type,
- LoFiState lofi_state,
+ int previews_state,
nasko 2016/12/08 22:19:32 PreviewsState
megjablon 2016/12/09 20:35:53 Done.
bool is_same_document_history_load,
bool is_history_navigation_in_new_child,
const base::TimeTicks& navigation_start,
@@ -158,7 +158,7 @@ std::unique_ptr<NavigationRequest> NavigationRequest::CreateBrowserInitiated(
std::unique_ptr<NavigationRequest> navigation_request(new NavigationRequest(
frame_tree_node, entry.ConstructCommonNavigationParams(
frame_entry, request_body, dest_url, dest_referrer,
- navigation_type, lofi_state, navigation_start),
+ navigation_type, previews_state, navigation_start),
BeginNavigationParams(entry.extra_headers(), net::LOAD_NORMAL,
false, // skip_service_worker
REQUEST_CONTEXT_TYPE_LOCATION),
@@ -405,11 +405,8 @@ void NavigationRequest::OnResponseStarted(
->service_worker_provider_host_id()
: kInvalidServiceWorkerProviderId;
- // Update the lofi state of the request.
- if (response->head.is_using_lofi)
- common_params_.lofi_state = LOFI_ON;
- else
- common_params_.lofi_state = LOFI_OFF;
+ // Update the previews state of the request.
+ common_params_.previews_state = response->head.previews_state;
// Select an appropriate renderer to commit the navigation.
RenderFrameHostImpl* render_frame_host =

Powered by Google App Engine
This is Rietveld 408576698